@@ -1,5 +1,5 @@
 package MooseX::Role::Parameterized::Meta::Parameter;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Moose;
 extends 'Moose::Meta::Attribute';
@@ -28,3 +28,20 @@ no Moose;
 
 1;
 
+__END__
+
+=head1 NAME
+
+MooseX::Role::Parameterized::Meta::Parameter - metaclass for parameters
+
+=head1 VERSION
+
+version 0.06
+
+=head1 DESCRIPTION
+
+This is the metaclass for parameter objects, a subclass of
+L<Moose::Meta::Attribute>. Its sole purpose is to make the default value
+of the C<is> option C<ro>.
+
+=cut
\ No newline at end of file
